/*******************************************************************************
 *  Copyright (c) 2015 Dani Zünd, Chair of Information Architecture, ETH Zürich.
 *  All rights reserved. This program and the accompanying materials
 *  are made available under the terms of the Eclipse Public License v1.0
 *  which accompanies this distribution, and is available at
 *  http://www.eclipse.org/legal/epl-v10.html
 *
 *  Contributors:
 *     Dani Zünd
 *******************************************************************************/
package geometry;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Iterator;
import java.util.List;

import agents.Agent;
import agents.Wall;

/**
 * Represents the geometry of the streets.
 * @author dani
 *
 */
public class GeometryHandler {

	// helpers
	private double inbetweenDist = 1;
	public double minX;
	public double minY;
	public double maxX;
	public double maxY;

	/**
	 * produces and places all the agents according to the input geometry.
	 * @return	an ArrayList of agents representing the walls.
	 */
	public ArrayList<Agent> getGeometry() {
		Iterator<Coordinates> it = coords.iterator();
		
		// calculate the minumum and maximum values of the whole.
        Coordinates curr;
		this.minX = Double.MAX_VALUE;
		this.minY = Double.MAX_VALUE;
		this.maxX = Double.MIN_VALUE;
		this.maxY = Double.MIN_VALUE;
		while (it.hasNext()) {
            curr = it.next();
			minX = Math.min(curr.x(), minX);
			minY = Math.min(curr.y(), minY);
			maxX = Math.max(curr.x(), maxX);
			maxY = Math.max(curr.y(), maxY);
		}
		
		ArrayList<Agent> wallElements= new ArrayList<Agent>();
		Coordinates first = this.coords.get(0);
		it = coords.iterator();
		curr = it.next();
		Coordinates next;
		// set the wall elements in equal distances between two corners.
		while(it.hasNext()) {
			next = it.next();
			double dist = Math.sqrt(next.sqDistance(curr));
			double xVec = next.x() - curr.x();
			double yVec = next.y() - curr.y();
			
			double fac = inbetweenDist/dist;
			double mult = 0;
			while (mult < 1) {
				double xCoord = (curr.x()-minX) + xVec * mult;
				double yCoord = (curr.y()-minY) + yVec * mult;
				wallElements.add(new Wall(xCoord, yCoord));
				mult += fac;
			}
			curr = next;
			if (curr.equals(first)) {
				if (it.hasNext()) {
					curr = it.next();
					first = curr;
				}
			}
		}
		return wallElements;
		
	}

	/**
	 * Coordinates of the corners of the geometry.
	 */
	private List<Coordinates> coords = Arrays.asList(
			new Coordinates( 682107.835, 247826.169),
			new Coordinates( 682111.528, 247864.478),
			new Coordinates( 682112.34, 247864.098),
			new Coordinates( 682112.381, 247864.19),
			new Coordinates( 682114.049, 247863.428),
			new Coordinates( 682114.012, 247863.321),
			new Coordinates( 682114.856, 247862.934),
			new Coordinates( 682115.008, 247863.287),
			new Coordinates( 682125.139, 247858.573),
			new Coordinates( 682129.458, 247856.564),
			new Coordinates( 682129.934, 247855.158),
			new Coordinates( 682131.899, 247854.244),
			new Coordinates( 682133.277, 247854.787),
			new Coordinates( 682137.615, 247852.768),
			new Coordinates( 682148.459, 247847.723),
			new Coordinates( 682151.521, 247849.676),
			new Coordinates( 682152.175, 247848.685),
			new Coordinates( 682154.336, 247850.036),
			new Coordinates( 682154.541, 247849.699),
			new Coordinates( 682157.594, 247851.622),
			new Coordinates( 682157.369, 247851.959),
			new Coordinates( 682159.52, 247853.33),
			new Coordinates( 682158.876, 247854.331),
			new Coordinates( 682161.968, 247856.295),
			new Coordinates( 682162.028, 247872.012),
			new Coordinates( 682162.188, 247872.01),
			new Coordinates( 682162.231, 247883.973),
			new Coordinates( 682162.241, 247886.849),
			new Coordinates( 682162.251, 247889.724),
			new Coordinates( 682162.346, 247916.166),
			new Coordinates( 682162.196, 247916.167),
			new Coordinates( 682162.196, 247916.284),
			new Coordinates( 682162.249, 247929.406),
			new Coordinates( 682161.507, 247933.066),
			new Coordinates( 682159.196, 247936.653),
			new Coordinates( 682155.569, 247939.242),
			new Coordinates( 682155.568, 247939.442),
			new Coordinates( 682153.77, 247939.977),
			new Coordinates( 682151.947, 247940.21),
			new Coordinates( 682144.763, 247949.043),
			new Coordinates( 682141.879, 247952.587),
			new Coordinates( 682149.616, 247967.673),
			new Coordinates( 682150.23, 247967.314),
			new Coordinates( 682156.172, 247963.833),
			new Coordinates( 682163.457, 247960.005),
			new Coordinates( 682172.217, 247955.378),
			new Coordinates( 682174.077, 247954.395),
			new Coordinates( 682186.834, 247947.665),
			new Coordinates( 682186.893, 247947.746),
			new Coordinates( 682196.989, 247942.439),
			new Coordinates( 682216.093, 247932.398),
			new Coordinates( 682219.351, 247933.094),
			new Coordinates( 682219.991, 247933.937),
			new Coordinates( 682226.272, 247942.212),
			new Coordinates( 682226.677, 247941.848),
			new Coordinates( 682231.533, 247947.837),
			new Coordinates( 682235.991, 247953.591),
			new Coordinates( 682239.218, 247957.377),
			new Coordinates( 682245.007, 247964.509),
			new Coordinates( 682244.572, 247968.393),
			new Coordinates( 682222.021, 247985.215),
			new Coordinates( 682215.209, 247990.300),
			new Coordinates( 682220.703, 247997.501),
			new Coordinates( 682228.135, 247991.952),
			new Coordinates( 682229.217, 247991.148),
			new Coordinates( 682252.678, 247973.648),
			new Coordinates( 682253.759, 247972.833),
			new Coordinates( 682258.561, 247969.251),
			new Coordinates( 682267.193, 247962.812),
			new Coordinates( 682268.106, 247964.015),
			new Coordinates( 682271.373, 247961.575),
			new Coordinates( 682271.496, 247961.483),
			new Coordinates( 682270.903, 247960.672),
			new Coordinates( 682272.943, 247959.159),
			new Coordinates( 682273.538, 247959.958),
			new Coordinates( 682281.161, 247954.265),
			new Coordinates( 682280.564, 247953.473),
			new Coordinates( 682284.409, 247950.617),
			new Coordinates( 682284.99, 247951.405),
			new Coordinates( 682292.609, 247945.715),
			new Coordinates( 682292.013, 247944.907),
			new Coordinates( 682294.044, 247943.406),
			new Coordinates( 682294.638, 247944.199),
			new Coordinates( 682294.794, 247944.083),
			new Coordinates( 682299.33, 247940.695),
			new Coordinates( 682298.437, 247939.452),
			new Coordinates( 682302.593, 247936.356),
			new Coordinates( 682305.105, 247934.485),
			new Coordinates( 682329.175, 247916.554),
			new Coordinates( 682330.242, 247918.005),
			new Coordinates( 682331.748, 247918.255),
			new Coordinates( 682332.846, 247919.758),
			new Coordinates( 682332.54, 247921.6),
			new Coordinates( 682341.991, 247934.419),
			new Coordinates( 682342.886, 247933.736),
			new Coordinates( 682344.982, 247936.545),
			new Coordinates( 682344.184, 247937.109),
			new Coordinates( 682348.94, 247943.756),
			new Coordinates( 682349.287, 247944.241),
			new Coordinates( 682350.769, 247946.313),
			new Coordinates( 682357.001, 247955.032),
			new Coordinates( 682356.584, 247957.586),
			new Coordinates( 682345.69, 247965.553),
			new Coordinates( 682341.675, 247968.493),
			new Coordinates( 682338.225, 247970.991),
			new Coordinates( 682332.899, 247974.892),
			new Coordinates( 682332.68, 247976.116),
			new Coordinates( 682330.979, 247977.331),
			new Coordinates( 682337.271, 247986.377),
			new Coordinates( 682339.638, 247984.659),
			new Coordinates( 682346.981, 247979.324),
			new Coordinates( 682349.157, 247977.743),
			new Coordinates( 682350.571, 247976.716),
			new Coordinates( 682358.474, 247970.974),
			new Coordinates( 682363.729, 247967.158),
			new Coordinates( 682366.064, 247967.541),
			new Coordinates( 682372.87, 247977.018),
			new Coordinates( 682380.833, 247988.112),
			new Coordinates( 682380.792, 247988.151),
			new Coordinates( 682381.812, 247989.576),
			new Coordinates( 682382.839, 247991.003),
			new Coordinates( 682391.982, 248003.701),
			new Coordinates( 682397.2, 248010.945),
			new Coordinates( 682396.697, 248013.939),
			new Coordinates( 682383.8, 248023.176),
			new Coordinates( 682382.36, 248024.207),
			new Coordinates( 682380.845, 248025.285),
			new Coordinates( 682380.913, 248025.386),
			new Coordinates( 682372.901, 248031.113),
			new Coordinates( 682372.955, 248031.188),
			new Coordinates( 682369.940, 248033.338),
			new Coordinates( 682376.679, 248043.025),
			new Coordinates( 682379.487, 248041.011),
			new Coordinates( 682381.766, 248039.376),
			new Coordinates( 682382.28, 248039.007),
			new Coordinates( 682389.464, 248033.858),
			new Coordinates( 682403.72, 248023.639),
			new Coordinates( 682406.753, 248024.142),
			new Coordinates( 682413.197, 248033.104),
			new Coordinates( 682413.335, 248033.296),
			new Coordinates( 682415.399, 248036.157),
			new Coordinates( 682422.16, 248045.582),
			new Coordinates( 682428.937, 248054.986),
			new Coordinates( 682430.984, 248057.846),
			new Coordinates( 682431.202, 248058.151),
			new Coordinates( 682437.547, 248066.982),
			new Coordinates( 682437.055, 248069.985),
			new Coordinates( 682438.456, 248072.13),
			new Coordinates( 682438.599, 248072.029),
			new Coordinates( 682438.738, 248071.922),
			new Coordinates( 682438.872, 248071.81),
			new Coordinates( 682439.002, 248071.693),
			new Coordinates( 682439.127, 248071.57),
			new Coordinates( 682439.247, 248071.443),
			new Coordinates( 682439.362, 248071.311),
			new Coordinates( 682439.472, 248071.175),
			new Coordinates( 682439.576, 248071.034),
			new Coordinates( 682439.674, 248070.889),
			new Coordinates( 682439.767, 248070.741),
			new Coordinates( 682439.854, 248070.589),
			new Coordinates( 682439.935, 248070.434),
			new Coordinates( 682440.009, 248070.275),
			new Coordinates( 682440.077, 248070.114),
			new Coordinates( 682440.139, 248069.95),
			new Coordinates( 682440.194, 248069.784),
			new Coordinates( 682440.243, 248069.616),
			new Coordinates( 682440.285, 248069.446),
			new Coordinates( 682440.32, 248069.274),
			new Coordinates( 682440.348, 248069.102),
			new Coordinates( 682440.369, 248068.928),
			new Coordinates( 682440.384, 248068.754),
			new Coordinates( 682440.391, 248068.579),
			new Coordinates( 682440.392, 248068.404),
			new Coordinates( 682440.386, 248068.229),
			new Coordinates( 682440.373, 248068.054),
			new Coordinates( 682440.353, 248067.88),
			new Coordinates( 682440.326, 248067.708),
			new Coordinates( 682440.292, 248067.536),
			new Coordinates( 682440.251, 248067.366),
			new Coordinates( 682440.204, 248067.197),
			new Coordinates( 682446.666, 248061.474),
			new Coordinates( 682451.427, 248057.258),
			new Coordinates( 682450.689, 248057.2),
			new Coordinates( 682450.707, 248056.96),
			new Coordinates( 682446.376, 248056.634),
			new Coordinates( 682446.359, 248056.862),
			new Coordinates( 682445.445, 248056.79),
			new Coordinates( 682444.925, 248056.065),
			new Coordinates( 682445.128, 248055.919),
			new Coordinates( 682442.658, 248052.483),
			new Coordinates( 682442.582, 248052.537),
			new Coordinates( 682442.099, 248051.863),
			new Coordinates( 682442.174, 248051.809),
			new Coordinates( 682439.747, 248048.432),
			new Coordinates( 682439.676, 248048.483),
			new Coordinates( 682439.187, 248047.801),
			new Coordinates( 682439.258, 248047.75),
			new Coordinates( 682436.834, 248044.378),
			new Coordinates( 682436.768, 248044.426),
			new Coordinates( 682436.255, 248043.712),
			new Coordinates( 682436.321, 248043.665),
			new Coordinates( 682433.91, 248040.309),
			new Coordinates( 682433.848, 248040.354),
			new Coordinates( 682433.339, 248039.643),
			new Coordinates( 682433.4, 248039.599),
			new Coordinates( 682430.982, 248036.234),
			new Coordinates( 682430.924, 248036.276),
			new Coordinates( 682430.435, 248035.593),
			new Coordinates( 682430.492, 248035.552),
			new Coordinates( 682428.068, 248032.18),
			new Coordinates( 682428.015, 248032.218),
			new Coordinates( 682427.504, 248031.505),
			new Coordinates( 682427.556, 248031.468),
			new Coordinates( 682425.132, 248028.095),
			new Coordinates( 682425.084, 248028.13),
			new Coordinates( 682424.601, 248027.456),
			new Coordinates( 682424.649, 248027.422),
			new Coordinates( 682422.232, 248024.059),
			new Coordinates( 682422.029, 248024.205),
			new Coordinates( 682421.42, 248023.371),
			new Coordinates( 682421.648, 248023.203),
			new Coordinates( 682422.248, 248022.782),
			new Coordinates( 682422.388, 248022.976),
			new Coordinates( 682425.782, 248020.533),
			new Coordinates( 682425.731, 248020.461),
			new Coordinates( 682426.442, 248019.952),
			new Coordinates( 682426.492, 248020.022),
			new Coordinates( 682429.873, 248017.589),
			new Coordinates( 682429.816, 248017.508),
			new Coordinates( 682430.531, 248017.002),
			new Coordinates( 682430.584, 248017.077),
			new Coordinates( 682433.986, 248014.628),
			new Coordinates( 682433.846, 248014.434),
			new Coordinates( 682434.666, 248013.842),
			new Coordinates( 682435.28, 248014.659),
			new Coordinates( 682435.048, 248014.833),
			new Coordinates( 682437.435, 248018.226),
			new Coordinates( 682437.517, 248018.168),
			new Coordinates( 682437.673, 248018.388),
			new Coordinates( 682437.887, 248018.185),
			new Coordinates( 682437.992, 248018.291),
			new Coordinates( 682439.788, 248016.5),
			new Coordinates( 682439.684, 248016.396),
			new Coordinates( 682440.111, 248015.964),
			new Coordinates( 682440.218, 248016.071),
			new Coordinates( 682443.357, 248012.94),
			new Coordinates( 682443.257, 248012.84),
			new Coordinates( 682443.689, 248012.408),
			new Coordinates( 682443.789, 248012.509),
			new Coordinates( 682446.926, 248009.38),
			new Coordinates( 682446.822, 248009.275),
			new Coordinates( 682447.254, 248008.846),
			new Coordinates( 682447.357, 248008.95),
			new Coordinates( 682450.491, 248005.825),
			new Coordinates( 682450.396, 248005.73),
			new Coordinates( 682450.82, 248005.294),
			new Coordinates( 682450.921, 248005.396),
			new Coordinates( 682454.056, 248002.269),
			new Coordinates( 682453.954, 248002.167),
			new Coordinates( 682454.382, 248001.738),
			new Coordinates( 682454.485, 248001.841),
			new Coordinates( 682457.627, 247998.707),
			new Coordinates( 682457.523, 247998.602),
			new Coordinates( 682457.954, 247998.178),
			new Coordinates( 682458.055, 247998.28),
			new Coordinates( 682461.194, 247995.15),
			new Coordinates( 682461.09, 247995.046),
			new Coordinates( 682461.522, 247994.617),
			new Coordinates( 682461.625, 247994.72),
			new Coordinates( 682464.759, 247991.594),
			new Coordinates( 682464.656, 247991.49),
			new Coordinates( 682465.086, 247991.063),
			new Coordinates( 682465.188, 247991.166),
			new Coordinates( 682468.327, 247988.035),
			new Coordinates( 682468.22, 247987.927),
			new Coordinates( 682468.635, 247987.475),
			new Coordinates( 682468.761, 247987.602),
			new Coordinates( 682471.893, 247984.478),
			new Coordinates( 682471.788, 247984.372),
			new Coordinates( 682472.222, 247983.942),
			new Coordinates( 682472.326, 247984.046),
			new Coordinates( 682475.46, 247980.921),
			new Coordinates( 682475.352, 247980.813),
			new Coordinates( 682475.789, 247980.386),
			new Coordinates( 682475.892, 247980.49),
			new Coordinates( 682479.033, 247977.357),
			new Coordinates( 682478.928, 247977.251),
			new Coordinates( 682479.361, 247976.824),
			new Coordinates( 682479.464, 247976.927),
			new Coordinates( 682482.49, 247973.909),
			new Coordinates( 682482.385, 247973.803),
			new Coordinates( 682482.803, 247973.379),
			new Coordinates( 682483.256, 247973.802),
			new Coordinates( 682483.15, 247973.907),
			new Coordinates( 682486.443, 247977.214),
			new Coordinates( 682486.547, 247977.11),
			new Coordinates( 682486.976, 247977.539),
			new Coordinates( 682486.871, 247977.644),
			new Coordinates( 682490.162, 247980.948),
			new Coordinates( 682490.272, 247980.838),
			new Coordinates( 682490.698, 247981.275),
			new Coordinates( 682490.592, 247981.38),
			new Coordinates( 682493.881, 247984.683),
			new Coordinates( 682493.987, 247984.577),
			new Coordinates( 682494.416, 247985.007),
			new Coordinates( 682494.31, 247985.113),
			new Coordinates( 682497.603, 247988.42),
			new Coordinates( 682497.709, 247988.314),
			new Coordinates( 682497.898, 247988.513),
			new Coordinates( 682498.085, 247988.33),
			new Coordinates( 682498.154, 247988.402),
			new Coordinates( 682501.092, 247985.449),
			new Coordinates( 682500.925, 247985.278),
			new Coordinates( 682501.626, 247984.593),
			new Coordinates( 682502.3, 247985.27),
			new Coordinates( 682502.121, 247985.445),
			new Coordinates( 682505.092, 247988.434),
			new Coordinates( 682505.149, 247988.377),
			new Coordinates( 682505.713, 247988.956),
			new Coordinates( 682505.662, 247989.007),
			new Coordinates( 682508.651, 247992.013),
			new Coordinates( 682508.716, 247991.948),
			new Coordinates( 682509.29, 247992.528),
			new Coordinates( 682509.226, 247992.592),
			new Coordinates( 682512.194, 247995.577),
			new Coordinates( 682512.367, 247995.411),
			new Coordinates( 682512.507, 247995.557),
			new Coordinates( 682512.952, 247996.021),
			new Coordinates( 682521.475, 247987.583),
			new Coordinates( 682520.941, 247987.05),
			new Coordinates( 682520.628, 247986.717),
			new Coordinates( 682520.791, 247986.569),
			new Coordinates( 682518.055, 247983.715),
			new Coordinates( 682517.941, 247983.816),
			new Coordinates( 682517.251, 247983.105),
			new Coordinates( 682517.348, 247983.019),
			new Coordinates( 682514.522, 247980.168),
			new Coordinates( 682514.418, 247980.279),
			new Coordinates( 682513.734, 247979.616),
			new Coordinates( 682513.847, 247979.515),
			new Coordinates( 682512.75, 247978.411),
			new Coordinates( 682511.126, 247976.766),
			new Coordinates( 682510.91, 247976.919),
			new Coordinates( 682510.153, 247976.145),
			new Coordinates( 682510.74, 247975.561),
			new Coordinates( 682491.081, 247955.743),
			new Coordinates( 682489.383, 247954.043),
			new Coordinates( 682488.963, 247954.455),
			new Coordinates( 682488.209, 247953.678),
			new Coordinates( 682488.415, 247953.481),
			new Coordinates( 682484.035, 247949.046),
			new Coordinates( 682483.817, 247949.23),
			new Coordinates( 682483.024, 247948.425),
			new Coordinates( 682483.414, 247948.055),
			new Coordinates( 682468.297, 247932.808),
			new Coordinates( 682461.938, 247926.375),
			new Coordinates( 682461.659, 247926.658),
			new Coordinates( 682461.803, 247926.82),
			new Coordinates( 682460.947, 247927.642),
			new Coordinates( 682460.088, 247926.774),
			new Coordinates( 682460.285, 247926.605),
			new Coordinates( 682459.956, 247926.268),
			new Coordinates( 682460.081, 247926.147),
			new Coordinates( 682456.911, 247922.949),
			new Coordinates( 682456.777, 247923.059),
			new Coordinates( 682456.136, 247922.375),
			new Coordinates( 682456.238, 247922.289),
			new Coordinates( 682453.139, 247919.101),
			new Coordinates( 682452.973, 247919.234),
			new Coordinates( 682452.293, 247918.546),
			new Coordinates( 682452.414, 247918.443),
			new Coordinates( 682449.244, 247915.207),
			new Coordinates( 682449.098, 247915.332),
			new Coordinates( 682448.808, 247915.005),
			new Coordinates( 682448.59, 247915.193),
			new Coordinates( 682447.761, 247914.337),
			new Coordinates( 682448.633, 247913.499),
			new Coordinates( 682448.814, 247913.687),
			new Coordinates( 682449.076, 247913.45),
			new Coordinates( 682445.497, 247909.866),
			new Coordinates( 682427.527, 247891.758),
			new Coordinates( 682427.103, 247892.16),
			new Coordinates( 682426.28, 247891.332),
			new Coordinates( 682426.521, 247891.109),
			new Coordinates( 682422.177, 247886.73),
			new Coordinates( 682421.941, 247886.93),
			new Coordinates( 682421.206, 247886.208),
			new Coordinates( 682421.615, 247885.816),
			new Coordinates( 682410.973, 247875.09),
			new Coordinates( 682400.215, 247864.278),
			new Coordinates( 682399.577, 247864.917),
			new Coordinates( 682398.835, 247864.159),
			new Coordinates( 682398.959, 247864.038),
			new Coordinates( 682396.072, 247861.093),
			new Coordinates( 682395.956, 247861.19),
			new Coordinates( 682395.265, 247860.489),
			new Coordinates( 682395.387, 247860.371),
			new Coordinates( 682392.52, 247857.412),
			new Coordinates( 682392.391, 247857.532),
			new Coordinates( 682391.656, 247856.786),
			new Coordinates( 682391.761, 247856.683),
			new Coordinates( 682388.897, 247853.764),
			new Coordinates( 682388.684, 247853.963),
			new Coordinates( 682388.019, 247853.229),
			new Coordinates( 682387.917, 247853.117),
			new Coordinates( 682388.716, 247852.387),
			new Coordinates( 682388.902, 247852.575),
			new Coordinates( 682392.104, 247849.62),
			new Coordinates( 682391.981, 247849.491),
			new Coordinates( 682392.733, 247848.781),
			new Coordinates( 682392.867, 247848.938),
			new Coordinates( 682396.21, 247845.761),
			new Coordinates( 682396.086, 247845.617),
			new Coordinates( 682396.759, 247844.982),
			new Coordinates( 682396.877, 247845.096),
			new Coordinates( 682400.131, 247841.983),
			new Coordinates( 682399.968, 247841.789),
			new Coordinates( 682400.753, 247841.077),
			new Coordinates( 682402.729, 247839.209),
			new Coordinates( 682404.168, 247837.848),
			new Coordinates( 682396.088, 247829.805),
			new Coordinates( 682393.86, 247831.904),
			new Coordinates( 682391.166, 247834.441),
			new Coordinates( 682381.333, 247843.743),
			new Coordinates( 682376.57, 247848.206),
			new Coordinates( 682369.504, 247854.868),
			new Coordinates( 682361.77, 247862.159),
			new Coordinates( 682354.827, 247868.692),
			new Coordinates( 682343.007, 247879.886),
			new Coordinates( 682334.786, 247887.631),
			new Coordinates( 682329.14, 247892.951),
			new Coordinates( 682325.606, 247892.551),
			new Coordinates( 682319.956, 247886.851),
			new Coordinates( 682311.014, 247877.814),
			new Coordinates( 682304.429, 247871.163),
			new Coordinates( 682301.874, 247868.583),
			new Coordinates( 682293.109, 247859.729),
			new Coordinates( 682293.012, 247856.707),
			new Coordinates( 682300.566, 247848.053),
			new Coordinates( 682308.048, 247839.467),
			new Coordinates( 682313.254, 247833.49),
			new Coordinates( 682319.819, 247825.995),
			new Coordinates( 682323.145, 247822.198),
			new Coordinates( 682325.533, 247819.482),
			new Coordinates( 682334.002, 247809.8),
			new Coordinates( 682339.267, 247803.794),
			new Coordinates( 682342.012, 247800.642),
			new Coordinates( 682349.24, 247792.373),
			new Coordinates( 682351.647, 247789.625),
			new Coordinates( 682353.545, 247787.458),
			new Coordinates( 682345.764, 247779.713),
			new Coordinates( 682344.204, 247781.514),
			new Coordinates( 682341.672, 247784.435),
			new Coordinates( 682336.007, 247790.93),
			new Coordinates( 682332.228, 247795.263),
			new Coordinates( 682329.923, 247797.904),
			new Coordinates( 682322.072, 247806.901),
			new Coordinates( 682314.305, 247815.793),
			new Coordinates( 682313.248, 247814.868),
			new Coordinates( 682313.096, 247815.046),
			new Coordinates( 682292.01, 247839.291),
			new Coordinates( 682291.786, 247839.548),
			new Coordinates( 682292.63, 247840.64),
			new Coordinates( 682285.545, 247848.761),
			new Coordinates( 682282.323, 247848.855),
			new Coordinates( 682276.526, 247843.029),
			new Coordinates( 682269.17, 247835.638),
			new Coordinates( 682269.241, 247835.569),
			new Coordinates( 682266.273, 247832.576),
			new Coordinates( 682263.473, 247829.766),
			new Coordinates( 682253.593, 247819.826),
			new Coordinates( 682245.666, 247811.853),
			new Coordinates( 682236.752, 247802.876),
			new Coordinates( 682236.771, 247802.497),
			new Coordinates( 682235.575, 247802.436),
			new Coordinates( 682235.612, 247801.718),
			new Coordinates( 682235.715, 247799.709),
			new Coordinates( 682236.912, 247799.771),
			new Coordinates( 682236.932, 247799.378),
			new Coordinates( 682245.221, 247792.619),
			new Coordinates( 682246.187, 247791.831),
			new Coordinates( 682247.313, 247790.913),
			new Coordinates( 682250.591, 247788.24),
			new Coordinates( 682250.684, 247788.36),
			new Coordinates( 682255.779, 247784.235),
			new Coordinates( 682255.675, 247784.096),
			new Coordinates( 682258.949, 247781.427),
			new Coordinates( 682267.488, 247774.466),
			new Coordinates( 682270.853, 247771.723),
			new Coordinates( 682270.94, 247771.84),
			new Coordinates( 682275.89, 247767.871),
			new Coordinates( 682275.766, 247767.72),
			new Coordinates( 682279.104, 247764.999),
			new Coordinates( 682282.616, 247762.138),
			new Coordinates( 682282.743, 247762.289),
			new Coordinates( 682287.344, 247758.521),
			new Coordinates( 682287.235, 247758.375),
			new Coordinates( 682287.851, 247757.874),
			new Coordinates( 682290.082, 247756.056),
			new Coordinates( 682290.749, 247755.513),
			new Coordinates( 682302.04, 247746.331),
			new Coordinates( 682305.988, 247742.587),
			new Coordinates( 682307.257, 247741.383),
			new Coordinates( 682296.660, 247730.835),
			new Coordinates( 682295.212, 247732.202),
			new Coordinates( 682293.909, 247733.431),
			new Coordinates( 682294.066, 247733.589),
			new Coordinates( 682266.107, 247756.315),
			new Coordinates( 682265.712, 247756.638),
			new Coordinates( 682264.147, 247757.915),
			new Coordinates( 682246.808, 247772.0),
			new Coordinates( 682237.46, 247779.594),
			new Coordinates( 682237.739, 247779.938),
			new Coordinates( 682234.782, 247782.34),
			new Coordinates( 682234.503, 247781.996),
			new Coordinates( 682226.182, 247788.755),
			new Coordinates( 682225.697, 247788.728),
			new Coordinates( 682224.934, 247789.573),
			new Coordinates( 682223.794, 247789.508),
			new Coordinates( 682223.108, 247788.581),
			new Coordinates( 682222.655, 247788.555),
			new Coordinates( 682196.762, 247762.535),
			new Coordinates( 682192.845, 247758.586),
			new Coordinates( 682161.656, 247768.823),
			new Coordinates( 682151.262, 247784.845),
			new Coordinates( 682149.874, 247786.785),
			new Coordinates( 682148.249, 247788.553),
			new Coordinates( 682141.92, 247794.804),
			new Coordinates( 682140.842, 247795.865),
			new Coordinates( 682139.761, 247796.923),
			new Coordinates( 682138.677, 247797.978),
			new Coordinates( 682137.59, 247799.029),
			new Coordinates( 682136.5, 247800.077),
			new Coordinates( 682135.406, 247801.122),
			new Coordinates( 682134.31, 247802.164),
			new Coordinates( 682133.21, 247803.202),
			new Coordinates( 682132.105, 247804.239),
			new Coordinates( 682130.997, 247805.273),
			new Coordinates( 682129.886, 247806.304),
			new Coordinates( 682128.771, 247807.331),
			new Coordinates( 682127.654, 247808.355),
			new Coordinates( 682126.533, 247809.375),
			new Coordinates( 682125.41, 247810.392),
			new Coordinates( 682124.283, 247811.406),
			new Coordinates( 682107.835, 247826.169),
			new Coordinates( 682379.354, 247861.405),
			new Coordinates( 682379.789, 247861.86),
			new Coordinates( 682379.959, 247862.029),
			new Coordinates( 682379.83, 247862.163),
			new Coordinates( 682382.696, 247865.111),
			new Coordinates( 682382.819, 247865.002),
			new Coordinates( 682383.421, 247865.623),
			new Coordinates( 682383.31, 247865.737),
			new Coordinates( 682386.182, 247868.683),
			new Coordinates( 682386.313, 247868.568),
			new Coordinates( 682386.978, 247869.268),
			new Coordinates( 682386.874, 247869.363),
			new Coordinates( 682389.765, 247872.316),
			new Coordinates( 682389.929, 247872.157),
			new Coordinates( 682390.636, 247872.868),
			new Coordinates( 682389.951, 247873.552),
			new Coordinates( 682389.771, 247873.357),
			new Coordinates( 682388.998, 247874.057),
			new Coordinates( 682390.17, 247875.27),
			new Coordinates( 682388.285, 247877.029),
			new Coordinates( 682387.12, 247875.839),
			new Coordinates( 682386.464, 247876.443),
			new Coordinates( 682386.571, 247876.572),
			new Coordinates( 682385.876, 247877.196),
			new Coordinates( 682385.772, 247877.071),
			new Coordinates( 682382.823, 247879.877),
			new Coordinates( 682382.932, 247880.0),
			new Coordinates( 682382.209, 247880.673),
			new Coordinates( 682382.094, 247880.556),
			new Coordinates( 682379.199, 247883.316),
			new Coordinates( 682379.291, 247883.425),
			new Coordinates( 682378.611, 247884.023),
			new Coordinates( 682378.512, 247883.918),
			new Coordinates( 682375.577, 247886.689),
			new Coordinates( 682375.709, 247886.815),
			new Coordinates( 682374.976, 247887.498),
			new Coordinates( 682374.858, 247887.375),
			new Coordinates( 682371.972, 247890.101),
			new Coordinates( 682372.095, 247890.235),
			new Coordinates( 682371.421, 247890.841),
			new Coordinates( 682371.326, 247890.729),
			new Coordinates( 682368.35, 247893.557),
			new Coordinates( 682368.462, 247893.675),
			new Coordinates( 682367.833, 247894.263),
			new Coordinates( 682367.733, 247894.145),
			new Coordinates( 682364.767, 247896.952),
			new Coordinates( 682364.873, 247897.07),
			new Coordinates( 682364.225, 247897.672),
			new Coordinates( 682364.123, 247897.553),
			new Coordinates( 682361.151, 247900.373),
			new Coordinates( 682361.245, 247900.515),
			new Coordinates( 682360.593, 247901.132),
			new Coordinates( 682360.492, 247901.012),
			new Coordinates( 682357.514, 247903.808),
			new Coordinates( 682357.641, 247903.956),
			new Coordinates( 682357.031, 247904.531),
			new Coordinates( 682356.908, 247904.392),
			new Coordinates( 682356.037, 247905.213),
			new Coordinates( 682356.754, 247906.204),
			new Coordinates( 682356.852, 247906.123),
			new Coordinates( 682357.347, 247906.806),
			new Coordinates( 682357.254, 247906.889),
			new Coordinates( 682359.643, 247910.205),
			new Coordinates( 682359.758, 247910.118),
			new Coordinates( 682360.295, 247910.853),
			new Coordinates( 682360.175, 247910.927),
			new Coordinates( 682362.598, 247914.27),
			new Coordinates( 682362.713, 247914.188),
			new Coordinates( 682363.29, 247914.979),
			new Coordinates( 682363.169, 247915.066),
			new Coordinates( 682365.495, 247918.304),
			new Coordinates( 682365.605, 247918.235),
			new Coordinates( 682366.176, 247919.009),
			new Coordinates( 682366.063, 247919.098),
			new Coordinates( 682368.468, 247922.444),
			new Coordinates( 682368.572, 247922.36),
			new Coordinates( 682369.089, 247923.074),
			new Coordinates( 682368.981, 247923.154),
			new Coordinates( 682371.425, 247926.491),
			new Coordinates( 682371.663, 247926.311),
			new Coordinates( 682372.269, 247927.1),
			new Coordinates( 682371.376, 247927.735),
			new Coordinates( 682371.267, 247927.562),
			new Coordinates( 682367.862, 247930.005),
			new Coordinates( 682367.942, 247930.101),
			new Coordinates( 682367.265, 247930.612),
			new Coordinates( 682367.167, 247930.471),
			new Coordinates( 682363.813, 247932.904),
			new Coordinates( 682363.883, 247933.009),
			new Coordinates( 682363.088, 247933.568),
			new Coordinates( 682363.015, 247933.454),
			new Coordinates( 682359.72, 247935.895),
			new Coordinates( 682359.853, 247936.081),
			new Coordinates( 682359.253, 247936.53),
			new Coordinates( 682359.016, 247936.707),
			new Coordinates( 682358.378, 247935.834),
			new Coordinates( 682358.642, 247935.631),
			new Coordinates( 682356.221, 247932.266),
			new Coordinates( 682356.11, 247932.336),
			new Coordinates( 682355.579, 247931.597),
			new Coordinates( 682355.7, 247931.501),
			new Coordinates( 682353.359, 247928.202),
			new Coordinates( 682353.218, 247928.318),
			new Coordinates( 682352.649, 247927.528),
			new Coordinates( 682352.758, 247927.45),
			new Coordinates( 682350.462, 247924.26),
			new Coordinates( 682350.354, 247924.34),
			new Coordinates( 682349.701, 247923.433),
			new Coordinates( 682349.813, 247923.354),
			new Coordinates( 682347.513, 247920.082),
			new Coordinates( 682347.365, 247920.188),
			new Coordinates( 682346.805, 247919.411),
			new Coordinates( 682346.928, 247919.329),
			new Coordinates( 682344.57, 247916.075),
			new Coordinates( 682344.454, 247916.145),
			new Coordinates( 682343.852, 247915.309),
			new Coordinates( 682343.966, 247915.234),
			new Coordinates( 682341.564, 247911.898),
			new Coordinates( 682341.448, 247911.97),
			new Coordinates( 682340.969, 247911.305),
			new Coordinates( 682341.108, 247911.203),
			new Coordinates( 682338.709, 247907.907),
			new Coordinates( 682338.584, 247907.992),
			new Coordinates( 682337.973, 247907.143),
			new Coordinates( 682338.094, 247907.052),
			new Coordinates( 682335.697, 247903.822),
			new Coordinates( 682335.472, 247904.002),
			new Coordinates( 682335.034, 247903.391),
			new Coordinates( 682334.884, 247903.182),
			new Coordinates( 682335.014, 247903.063),
			new Coordinates( 682335.589, 247902.538),
			new Coordinates( 682335.789, 247902.777),
			new Coordinates( 682338.748, 247900.017),
			new Coordinates( 682338.62, 247899.885),
			new Coordinates( 682339.392, 247899.155),
			new Coordinates( 682339.521, 247899.283),
			new Coordinates( 682342.466, 247896.506),
			new Coordinates( 682342.339, 247896.37),
			new Coordinates( 682342.969, 247895.774),
			new Coordinates( 682343.095, 247895.905),
			new Coordinates( 682346.128, 247893.066),
			new Coordinates( 682345.993, 247892.917),
			new Coordinates( 682346.636, 247892.31),
			new Coordinates( 682346.76, 247892.455),
			new Coordinates( 682349.693, 247889.698),
			new Coordinates( 682349.559, 247889.548),
			new Coordinates( 682350.252, 247888.893),
			new Coordinates( 682350.378, 247889.041),
			new Coordinates( 682353.322, 247886.28),
			new Coordinates( 682353.18, 247886.126),
			new Coordinates( 682353.904, 247885.442),
			new Coordinates( 682354.024, 247885.567),
			new Coordinates( 682356.949, 247882.84),
			new Coordinates( 682356.81, 247882.696),
			new Coordinates( 682357.553, 247881.993),
			new Coordinates( 682357.68, 247882.129),
			new Coordinates( 682360.575, 247879.387),
			new Coordinates( 682360.453, 247879.253),
			new Coordinates( 682361.139, 247878.605),
			new Coordinates( 682361.246, 247878.723),
			new Coordinates( 682364.201, 247875.982),
			new Coordinates( 682364.068, 247875.837),
			new Coordinates( 682364.764, 247875.179),
			new Coordinates( 682364.882, 247875.308),
			new Coordinates( 682367.833, 247872.563),
			new Coordinates( 682367.689, 247872.415),
			new Coordinates( 682368.368, 247871.774),
			new Coordinates( 682368.486, 247871.907),
			new Coordinates( 682371.504, 247869.051),
			new Coordinates( 682371.382, 247868.928),
			new Coordinates( 682372.063, 247868.286),
			new Coordinates( 682372.185, 247868.417),
			new Coordinates( 682375.039, 247865.755),
			new Coordinates( 682374.902, 247865.607),
			new Coordinates( 682375.614, 247864.935),
			new Coordinates( 682375.749, 247865.073),
			new Coordinates( 682378.775, 247862.251),
			new Coordinates( 682378.525, 247862.004),
			new Coordinates( 682379.262, 247861.31),
			new Coordinates( 682379.354, 247861.405),
			new Coordinates( 682263.947, 247871.668),
			new Coordinates( 682261.215, 247874.627),
			new Coordinates( 682234.736, 247903.298),
			new Coordinates( 682224.307, 247914.583),
			new Coordinates( 682224.208, 247914.511),
			new Coordinates( 682203.622, 247925.371),
			new Coordinates( 682185.132, 247935.12),
			new Coordinates( 682183.528, 247933.957),
			new Coordinates( 682183.031, 247932.788),
			new Coordinates( 682182.166, 247930.755),
			new Coordinates( 682180.79, 247930.739),
			new Coordinates( 682180.789, 247925.675),
			new Coordinates( 682180.244, 247925.589),
			new Coordinates( 682180.225, 247924.16),
			new Coordinates( 682180.198, 247918.319),
			new Coordinates( 682180.182, 247914.341),
			new Coordinates( 682180.104, 247895.395),
			new Coordinates( 682188.059, 247890.847),
			new Coordinates( 682188.431, 247890.635),
			new Coordinates( 682188.399, 247890.579),
			new Coordinates( 682211.399, 247877.395),
			new Coordinates( 682210.906, 247876.551),
			new Coordinates( 682224.715, 247868.621),
			new Coordinates( 682224.768, 247868.679),
			new Coordinates( 682225.185, 247868.44),
			new Coordinates( 682225.338, 247868.622),
			new Coordinates( 682243.142, 247856.442),
			new Coordinates( 682246.426, 247854.068),
			new Coordinates( 682249.69, 247851.704),
			new Coordinates( 682260.394, 247843.735),
			new Coordinates( 682267.838, 247851.241),
			new Coordinates( 682263.947, 247871.668),
			new Coordinates( 682310.593, 247894.232),
			new Coordinates( 682309.751, 247897.15),
			new Coordinates( 682296.689, 247899.986),
			new Coordinates( 682284.24, 247902.69),
			new Coordinates( 682267.347, 247906.361),
			new Coordinates( 682255.332, 247908.98),
			new Coordinates( 682252.199, 247909.647),
			new Coordinates( 682249.452, 247905.047),
			new Coordinates( 682251.579, 247902.745),
			new Coordinates( 682252.222, 247902.049),
			new Coordinates( 682259.504, 247894.168),
			new Coordinates( 682264.85, 247888.382),
			new Coordinates( 682267.168, 247885.872),
			new Coordinates( 682274.002, 247878.471),
			new Coordinates( 682282.625, 247869.132),
			new Coordinates( 682285.516, 247869.072),
			new Coordinates( 682292.487, 247876.102),
			new Coordinates( 682292.537, 247876.072),
			new Coordinates( 682300.859, 247884.461),
			new Coordinates( 682310.593, 247894.232),
			new Coordinates( 682228.018, 247927.227),
			new Coordinates( 682252.034, 247921.976),
			new Coordinates( 682261.795, 247919.864),
			new Coordinates( 682275.503, 247916.888),
			new Coordinates( 682279.009, 247916.127),
			new Coordinates( 682282.63, 247915.341),
			new Coordinates( 682289.5, 247913.849),
			new Coordinates( 682289.315, 247912.995),
			new Coordinates( 682289.432, 247912.97),
			new Coordinates( 682289.407, 247912.852),
			new Coordinates( 682291.976, 247912.296),
			new Coordinates( 682292.002, 247912.413),
			new Coordinates( 682292.119, 247912.387),
			new Coordinates( 682292.304, 247913.24),
			new Coordinates( 682293.376, 247913.01),
			new Coordinates( 682296.169, 247912.405),
			new Coordinates( 682297.236, 247912.169),
			new Coordinates( 682297.05, 247911.316),
			new Coordinates( 682297.167, 247911.291),
			new Coordinates( 682297.142, 247911.173),
			new Coordinates( 682299.701, 247910.615),
			new Coordinates( 682299.727, 247910.732),
			new Coordinates( 682299.844, 247910.706),
			new Coordinates( 682300.031, 247911.562),
			new Coordinates( 682300.989, 247911.357),
			new Coordinates( 682306.894, 247910.072),
			new Coordinates( 682307.099, 247910.331),
			new Coordinates( 682307.197, 247910.262),
			new Coordinates( 682308.032, 247911.326),
			new Coordinates( 682308.444, 247911.87),
			new Coordinates( 682309.231, 247911.267),
			new Coordinates( 682310.192, 247912.475),
			new Coordinates( 682309.396, 247913.099),
			new Coordinates( 682309.814, 247913.642),
			new Coordinates( 682310.647, 247914.716),
			new Coordinates( 682310.555, 247914.808),
			new Coordinates( 682310.775, 247915.068),
			new Coordinates( 682306.143, 247918.987),
			new Coordinates( 682305.401, 247919.614),
			new Coordinates( 682305.56, 247919.802),
			new Coordinates( 682305.97, 247920.286),
			new Coordinates( 682305.879, 247920.364),
			new Coordinates( 682305.956, 247920.456),
			new Coordinates( 682303.946, 247922.157),
			new Coordinates( 682303.868, 247922.065),
			new Coordinates( 682303.777, 247922.142),
			new Coordinates( 682303.208, 247921.47),
			new Coordinates( 682302.374, 247922.175),
			new Coordinates( 682300.181, 247924.02),
			new Coordinates( 682299.365, 247924.71),
			new Coordinates( 682299.932, 247925.381),
			new Coordinates( 682299.841, 247925.458),
			new Coordinates( 682299.918, 247925.55),
			new Coordinates( 682297.905, 247927.253),
			new Coordinates( 682297.828, 247927.161),
			new Coordinates( 682297.736, 247927.238),
			new Coordinates( 682297.331, 247926.758),
			new Coordinates( 682291.365, 247931.801),
			new Coordinates( 682289.141, 247933.48),
			new Coordinates( 682287.955, 247934.377),
			new Coordinates( 682278.755, 247941.334),
			new Coordinates( 682277.404, 247942.355),
			new Coordinates( 682275.685, 247943.655),
			new Coordinates( 682262.594, 247953.557),
			new Coordinates( 682262.555, 247953.506),
			new Coordinates( 682259.496, 247955.797),
			new Coordinates( 682252.426, 247961.094),
			new Coordinates( 682249.581, 247960.743),
			new Coordinates( 682241.297, 247950.493),
			new Coordinates( 682241.64, 247950.217),
			new Coordinates( 682237.374, 247944.949),
			new Coordinates( 682237.266, 247944.818),
			new Coordinates( 682226.621, 247931.066),
			new Coordinates( 682228.018, 247927.227),
			new Coordinates( 682366.332, 247946.366),
			new Coordinates( 682366.848, 247945.992),
			new Coordinates( 682379.075, 247937.113),
			new Coordinates( 682398.812, 247964.466),
			new Coordinates( 682399.338, 247964.082),
			new Coordinates( 682408.25, 247976.507),
			new Coordinates( 682407.733, 247976.874),
			new Coordinates( 682427.423, 248004.186),
			new Coordinates( 682420.553, 248009.222),
			new Coordinates( 682419.335, 248010.102),
			new Coordinates( 682415.146, 248013.151),
			new Coordinates( 682414.659, 248013.496),
			new Coordinates( 682394.913, 247986.071),
			new Coordinates( 682394.398, 247986.454),
			new Coordinates( 682385.473, 247974.076),
			new Coordinates( 682386.008, 247973.704),
			new Coordinates( 682366.332, 247946.366),
			new Coordinates( 682408.469, 247936.362),
			new Coordinates( 682408.326, 247936.358),
			new Coordinates( 682408.184, 247936.351),
			new Coordinates( 682408.042, 247936.341),
			new Coordinates( 682407.9, 247936.327),
			new Coordinates( 682407.758, 247936.309),
			new Coordinates( 682407.617, 247936.288),
			new Coordinates( 682407.477, 247936.264),
			new Coordinates( 682407.337, 247936.236),
			new Coordinates( 682407.198, 247936.205),
			new Coordinates( 682407.059, 247936.171),
			new Coordinates( 682406.922, 247936.133),
			new Coordinates( 682406.785, 247936.092),
			new Coordinates( 682406.65, 247936.047),
			new Coordinates( 682406.516, 247935.999),
			new Coordinates( 682406.382, 247935.948),
			new Coordinates( 682406.251, 247935.894),
			new Coordinates( 682406.12, 247935.837),
			new Coordinates( 682405.991, 247935.776),
			new Coordinates( 682405.863, 247935.712),
			new Coordinates( 682405.738, 247935.646),
			new Coordinates( 682405.613, 247935.576),
			new Coordinates( 682405.491, 247935.503),
			new Coordinates( 682405.37, 247935.427),
			new Coordinates( 682405.251, 247935.348),
			new Coordinates( 682405.134, 247935.267),
			new Coordinates( 682405.019, 247935.182),
			new Coordinates( 682404.906, 247935.095),
			new Coordinates( 682404.796, 247935.005),
			new Coordinates( 682404.687, 247934.912),
			new Coordinates( 682404.581, 247934.817),
			new Coordinates( 682404.477, 247934.719),
			new Coordinates( 682404.376, 247934.619),
			new Coordinates( 682404.277, 247934.516),
			new Coordinates( 682404.181, 247934.411),
			new Coordinates( 682404.087, 247934.304),
			new Coordinates( 682403.996, 247934.194),
			new Coordinates( 682403.907, 247934.082),
			new Coordinates( 682403.821, 247933.969),
			new Coordinates( 682403.739, 247933.853),
			new Coordinates( 682403.658, 247933.735),
			new Coordinates( 682403.581, 247933.615),
			new Coordinates( 682403.507, 247933.493),
			new Coordinates( 682403.436, 247933.369),
			new Coordinates( 682403.368, 247933.244),
			new Coordinates( 682403.302, 247933.117),
			new Coordinates( 682403.24, 247932.989),
			new Coordinates( 682403.181, 247932.859),
			new Coordinates( 682403.126, 247932.728),
			new Coordinates( 682403.073, 247932.595),
			new Coordinates( 682403.024, 247932.461),
			new Coordinates( 682402.978, 247932.327),
			new Coordinates( 682402.935, 247932.19),
			new Coordinates( 682402.896, 247932.053),
			new Coordinates( 682402.86, 247931.915),
			new Coordinates( 682402.827, 247931.777),
			new Coordinates( 682402.798, 247931.637),
			new Coordinates( 682402.772, 247931.497),
			new Coordinates( 682402.749, 247931.356),
			new Coordinates( 682402.73, 247931.215),
			new Coordinates( 682402.715, 247931.073),
			new Coordinates( 682402.703, 247930.931),
			new Coordinates( 682402.694, 247930.789),
			new Coordinates( 682402.689, 247930.646),
			new Coordinates( 682402.687, 247930.503),
			new Coordinates( 682402.689, 247930.361),
			new Coordinates( 682402.694, 247930.218),
			new Coordinates( 682402.703, 247930.076),
			new Coordinates( 682402.715, 247929.934),
			new Coordinates( 682402.73, 247929.792),
			new Coordinates( 682402.749, 247929.651),
			new Coordinates( 682402.772, 247929.51),
			new Coordinates( 682402.798, 247929.37),
			new Coordinates( 682402.827, 247929.23),
			new Coordinates( 682402.86, 247929.092),
			new Coordinates( 682402.896, 247928.954),
			new Coordinates( 682402.935, 247928.817),
			new Coordinates( 682402.978, 247928.68),
			new Coordinates( 682403.024, 247928.546),
			new Coordinates( 682403.073, 247928.412),
			new Coordinates( 682403.126, 247928.279),
			new Coordinates( 682403.181, 247928.148),
			new Coordinates( 682403.24, 247928.018),
			new Coordinates( 682403.302, 247927.89),
			new Coordinates( 682403.368, 247927.763),
			new Coordinates( 682403.436, 247927.638),
			new Coordinates( 682403.507, 247927.514),
			new Coordinates( 682403.581, 247927.392),
			new Coordinates( 682403.658, 247927.272),
			new Coordinates( 682403.739, 247927.154),
			new Coordinates( 682403.821, 247927.038),
			new Coordinates( 682403.907, 247926.925),
			new Coordinates( 682403.996, 247926.813),
			new Coordinates( 682404.087, 247926.703),
			new Coordinates( 682404.181, 247926.596),
			new Coordinates( 682404.277, 247926.491),
			new Coordinates( 682404.376, 247926.388),
			new Coordinates( 682404.477, 247926.288),
			new Coordinates( 682404.581, 247926.19),
			new Coordinates( 682404.687, 247926.095),
			new Coordinates( 682404.796, 247926.002),
			new Coordinates( 682404.906, 247925.912),
			new Coordinates( 682405.019, 247925.825),
			new Coordinates( 682405.134, 247925.74),
			new Coordinates( 682405.251, 247925.659),
			new Coordinates( 682405.37, 247925.58),
			new Coordinates( 682405.491, 247925.504),
			new Coordinates( 682405.613, 247925.431),
			new Coordinates( 682405.738, 247925.361),
			new Coordinates( 682405.863, 247925.295),
			new Coordinates( 682405.991, 247925.231),
			new Coordinates( 682406.12, 247925.17),
			new Coordinates( 682406.251, 247925.113),
			new Coordinates( 682406.382, 247925.059),
			new Coordinates( 682406.516, 247925.008),
			new Coordinates( 682406.65, 247924.96),
			new Coordinates( 682406.785, 247924.915),
			new Coordinates( 682406.922, 247924.874),
			new Coordinates( 682407.059, 247924.836),
			new Coordinates( 682407.198, 247924.802),
			new Coordinates( 682407.337, 247924.771),
			new Coordinates( 682407.477, 247924.743),
			new Coordinates( 682407.617, 247924.719),
			new Coordinates( 682407.758, 247924.698),
			new Coordinates( 682407.9, 247924.68),
			new Coordinates( 682408.042, 247924.666),
			new Coordinates( 682408.184, 247924.656),
			new Coordinates( 682408.326, 247924.649),
			new Coordinates( 682408.469, 247924.645),
			new Coordinates( 682408.612, 247924.649),
			new Coordinates( 682408.754, 247924.656),
			new Coordinates( 682408.896, 247924.666),
			new Coordinates( 682409.038, 247924.68),
			new Coordinates( 682409.18, 247924.698),
			new Coordinates( 682409.321, 247924.719),
			new Coordinates( 682409.461, 247924.743),
			new Coordinates( 682409.601, 247924.771),
			new Coordinates( 682409.74, 247924.802),
			new Coordinates( 682409.879, 247924.836),
			new Coordinates( 682410.016, 247924.874),
			new Coordinates( 682410.153, 247924.915),
			new Coordinates( 682410.288, 247924.96),
			new Coordinates( 682410.422, 247925.008),
			new Coordinates( 682410.556, 247925.059),
			new Coordinates( 682410.687, 247925.113),
			new Coordinates( 682410.818, 247925.17),
			new Coordinates( 682410.947, 247925.231),
			new Coordinates( 682411.075, 247925.295),
			new Coordinates( 682411.2, 247925.361),
			new Coordinates( 682411.325, 247925.431),
			new Coordinates( 682411.447, 247925.504),
			new Coordinates( 682411.568, 247925.58),
			new Coordinates( 682411.687, 247925.659),
			new Coordinates( 682411.804, 247925.74),
			new Coordinates( 682411.919, 247925.825),
			new Coordinates( 682412.032, 247925.912),
			new Coordinates( 682412.142, 247926.002),
			new Coordinates( 682412.251, 247926.095),
			new Coordinates( 682412.357, 247926.19),
			new Coordinates( 682412.461, 247926.288),
			new Coordinates( 682412.562, 247926.388),
			new Coordinates( 682412.661, 247926.491),
			new Coordinates( 682412.757, 247926.596),
			new Coordinates( 682412.851, 247926.703),
			new Coordinates( 682412.942, 247926.813),
			new Coordinates( 682413.031, 247926.925),
			new Coordinates( 682413.117, 247927.038),
			new Coordinates( 682413.199, 247927.154),
			new Coordinates( 682413.28, 247927.272),
			new Coordinates( 682413.357, 247927.392),
			new Coordinates( 682413.431, 247927.514),
			new Coordinates( 682413.502, 247927.638),
			new Coordinates( 682413.57, 247927.763),
			new Coordinates( 682413.636, 247927.89),
			new Coordinates( 682413.698, 247928.018),
			new Coordinates( 682413.757, 247928.148),
			new Coordinates( 682413.812, 247928.279),
			new Coordinates( 682413.865, 247928.412),
			new Coordinates( 682413.914, 247928.546),
			new Coordinates( 682413.96, 247928.68),
			new Coordinates( 682414.003, 247928.817),
			new Coordinates( 682414.042, 247928.954),
			new Coordinates( 682414.078, 247929.092),
			new Coordinates( 682414.111, 247929.23),
			new Coordinates( 682414.14, 247929.37),
			new Coordinates( 682414.166, 247929.51),
			new Coordinates( 682414.189, 247929.651),
			new Coordinates( 682414.208, 247929.792),
			new Coordinates( 682414.223, 247929.934),
			new Coordinates( 682414.235, 247930.076),
			new Coordinates( 682414.244, 247930.218),
			new Coordinates( 682414.249, 247930.361),
			new Coordinates( 682414.251, 247930.504),
			new Coordinates( 682414.249, 247930.646),
			new Coordinates( 682414.244, 247930.789),
			new Coordinates( 682414.235, 247930.931),
			new Coordinates( 682414.223, 247931.073),
			new Coordinates( 682414.208, 247931.215),
			new Coordinates( 682414.189, 247931.356),
			new Coordinates( 682414.166, 247931.497),
			new Coordinates( 682414.14, 247931.637),
			new Coordinates( 682414.111, 247931.777),
			new Coordinates( 682414.078, 247931.915),
			new Coordinates( 682414.042, 247932.053),
			new Coordinates( 682414.003, 247932.19),
			new Coordinates( 682413.96, 247932.327),
			new Coordinates( 682413.914, 247932.461),
			new Coordinates( 682413.865, 247932.595),
			new Coordinates( 682413.812, 247932.728),
			new Coordinates( 682413.757, 247932.859),
			new Coordinates( 682413.698, 247932.989),
			new Coordinates( 682413.636, 247933.117),
			new Coordinates( 682413.57, 247933.244),
			new Coordinates( 682413.502, 247933.369),
			new Coordinates( 682413.431, 247933.493),
			new Coordinates( 682413.357, 247933.615),
			new Coordinates( 682413.28, 247933.735),
			new Coordinates( 682413.199, 247933.853),
			new Coordinates( 682413.117, 247933.969),
			new Coordinates( 682413.031, 247934.082),
			new Coordinates( 682412.942, 247934.194),
			new Coordinates( 682412.851, 247934.304),
			new Coordinates( 682412.757, 247934.411),
			new Coordinates( 682412.661, 247934.516),
			new Coordinates( 682412.562, 247934.619),
			new Coordinates( 682412.461, 247934.719),
			new Coordinates( 682412.357, 247934.817),
			new Coordinates( 682412.251, 247934.912),
			new Coordinates( 682412.142, 247935.005),
			new Coordinates( 682412.032, 247935.095),
			new Coordinates( 682411.919, 247935.182),
			new Coordinates( 682411.804, 247935.267),
			new Coordinates( 682411.687, 247935.348),
			new Coordinates( 682411.568, 247935.427),
			new Coordinates( 682411.447, 247935.503),
			new Coordinates( 682411.325, 247935.576),
			new Coordinates( 682411.2, 247935.646),
			new Coordinates( 682411.075, 247935.712),
			new Coordinates( 682410.947, 247935.776),
			new Coordinates( 682410.818, 247935.837),
			new Coordinates( 682410.687, 247935.894),
			new Coordinates( 682410.556, 247935.948),
			new Coordinates( 682410.422, 247935.999),
			new Coordinates( 682410.288, 247936.047),
			new Coordinates( 682410.153, 247936.092),
			new Coordinates( 682410.016, 247936.133),
			new Coordinates( 682409.879, 247936.171),
			new Coordinates( 682409.74, 247936.205),
			new Coordinates( 682409.601, 247936.236),
			new Coordinates( 682409.461, 247936.264),
			new Coordinates( 682409.321, 247936.288),
			new Coordinates( 682409.18, 247936.309),
			new Coordinates( 682409.038, 247936.327),
			new Coordinates( 682408.896, 247936.341),
			new Coordinates( 682408.754, 247936.351),
			new Coordinates( 682408.612, 247936.358),
			new Coordinates( 682408.469, 247936.362),
			new Coordinates(682189, 247865),
			new Coordinates(682201, 247857),
			new Coordinates(682194, 247846),
			new Coordinates(682182, 247854),
			new Coordinates(682189, 247865),
			new Coordinates(682222, 247828),
			new Coordinates(682211, 247835),
			new Coordinates(682217, 247845),
			new Coordinates(682228, 247838),
			new Coordinates(682222, 247828)  
        );
	

}
